/**
 * Ultrasonic sensor uses NewPing library
 * https://bitbucket.org/teckel12/arduino-new-ping/wiki/Home
 * 
 * Display uses U8g2 library
 * https://github.com/olikraus/u8g2
 */

#include <NewPing.h>
#include <U8g2lib.h>

#define TRIGGER_PIN  4  // Arduino pin tied to trigger pin on the ultrasonic sensor.
#define ECHO_PIN     5  // Arduino pin tied to echo pin on the ultrasonic sensor.
#define MAX_DISTANCE 300 // Maximum distance we want to ping for (in centimeters). Maximum sensor distance is rated at 400-500cm.

NewPing sonar(TRIGGER_PIN, ECHO_PIN, MAX_DISTANCE); // NewPing setup of pins and maximum distance.

// display setup:
// software i2c:
//U8X8_SSD1306_128X64_NONAME_SW_I2C u8x8(7, 8, U8X8_PIN_NONE);
// hardware i2c:
U8X8_SSD1306_128X64_NONAME_HW_I2C display(U8X8_PIN_NONE);

char buf[10]; // text buffer; to be able to use draw2x2String to show the value

void setup() {
  Serial.begin(9600); // start serial port output, check for same speed at Serial Monitor

  // initialize display:
  display.begin();
  display.setPowerSave(0);

  display.setFont(u8x8_font_pxplusibmcgathin_f);
  display.drawString(0,0,"Ultrasonic"); // draw text on line 0
  display.drawString(0,1,"sensor"); // draw text on line 1
  display.draw2x2String(0,3,"Distance"); // draw text in 2x2 font on line 3
}

void loop() {
  unsigned int distance = sonar.convert_cm(sonar.ping_median(5)); // read distance from ultrasonic sensor (using median of 5 iterations)
  // display value in serial monitor:
  Serial.print("Dist.: ");
  Serial.println(distance);

  // display value on the display in a large (2x2) font:
  snprintf(buf, 10, "%3d", distance); // put value of distance into string buffer; %3d means we have 3 decimal places (because our value is always between 0 - 999)
  display.draw2x2String(0,6,buf);

  delay(500); // wait half a second
}
